@@ -4,8 +4,11 @@
 if (!isGeneric("expand"))
     setGeneric("expand", function(x, ...) standardGeneric("expand"))
 
-if (!isGeneric("tcrossprod"))
-    setGeneric("tcrossprod", function(x) standardGeneric("tcrossprod"))
+## if (!isGeneric("tcrossprod"))
+##   setGeneric("tcrossprod", function(x, y = NULL) standardGeneric("tcrossprod"))
+if (!exists("tcrossprod"))# R <= 2.2.x :
+    tcrossprod <- function(x, y = NULL) x %*% t(if(is.null(y)) x else y)
+## will become generic by setMethod(..)
 
 if (!isGeneric("isDiagonal"))
     setGeneric("isDiagonal", function(object, ...)
