@@ -36,7 +36,9 @@ static R_CallMethodDef CallEntries[] = {
     {"Cholesky_validate", (DL_FUNC) &Cholesky_validate, 1},
     {"Csparse_Csparse_prod", (DL_FUNC) &Csparse_Csparse_prod, 2},
     {"Csparse_dense_prod", (DL_FUNC) &Csparse_dense_prod, 2},
+    {"Csparse_dense_crossprod", (DL_FUNC) &Csparse_dense_crossprod, 2},
     {"Csparse_crossprod", (DL_FUNC) &Csparse_crossprod, 3},
+    {"Csparse_to_dense", (DL_FUNC) &Csparse_to_dense, 1},
     {"Csparse_to_Tsparse", (DL_FUNC) &Csparse_to_Tsparse, 1},
     {"Csparse_transpose", (DL_FUNC) &Csparse_transpose, 1},
     {"Csparse_validate", (DL_FUNC) &Csparse_validate, 1},
@@ -52,7 +54,6 @@ static R_CallMethodDef CallEntries[] = {
     {"Tsparse_validate", (DL_FUNC) &Tsparse_validate, 1},
     {"Tsparse_to_Csparse", (DL_FUNC) &Tsparse_to_Csparse, 1},
     {"csc_check_column_sorting", (DL_FUNC) &csc_check_column_sorting, 1},
-    {"Tsparse_validate", (DL_FUNC) &Tsparse_validate, 1},
     {"csc_crossprod", (DL_FUNC) &csc_crossprod, 1},
     {"csc_getDiag", (DL_FUNC) &csc_getDiag, 1},
     {"csc_matrix_crossprod", (DL_FUNC) &csc_matrix_crossprod, 3},
@@ -63,6 +64,7 @@ static R_CallMethodDef CallEntries[] = {
     {"csc_to_dgeMatrix", (DL_FUNC) &csc_to_dgeMatrix, 1},
     {"csc_to_matrix", (DL_FUNC) &csc_to_matrix, 1},
     {"csc_transpose", (DL_FUNC) &csc_transpose, 1},
+    {"dense_to_Csparse", (DL_FUNC) &dense_to_Csparse, 1},
     {"dgBCMatrix_to_dgCMatrix", (DL_FUNC) &dgBCMatrix_to_dgCMatrix, 1},
     {"dgBCMatrix_to_dgTMatrix", (DL_FUNC) &dgBCMatrix_to_dgTMatrix, 1},
     {"dgBCMatrix_validate", (DL_FUNC) &dgBCMatrix_validate, 1},
