@@ -1,5 +1,5 @@
-#ifndef MATRIX_LMEUTILS_H
-#define MATRIX_LMEUTILS_H
+#ifndef MATRIX_LMER_H
+#define MATRIX_LMER_H
 
 #include "Mutils.h"
 #include "triplet_to_col.h"
@@ -12,6 +12,7 @@
 #include "lgCMatrix.h"
 #include "lCholCMatrix.h"
 #include "Rmath.h"
+#include "chm_common.h"
 #include <R_ext/Lapack.h>
 #include <R_ext/Constants.h>
 
@@ -48,5 +49,12 @@ SEXP lmer_simulate(SEXP x, SEXP np, SEXP fxdp, SEXP mmats,
 		   SEXP useScP);
 SEXP lmer_update_y(SEXP x, SEXP y, SEXP mm);
 SEXP lmer_set_initial(SEXP x, SEXP iv);
+SEXP mer2_coef(SEXP x, SEXP pType);
+SEXP mer2_coefGets(SEXP x, SEXP coef, SEXP pType);
+SEXP mer2_create(SEXP random, SEXP Xp, SEXP yp, SEXP method);
+SEXP mer2_factor(SEXP x);
+SEXP mer2_initial(SEXP x);
+SEXP mer2_pMatrix(SEXP x);
+SEXP mer2_dtCMatrix(SEXP x);
 
 #endif
